FieldVec

Type Alias FieldVec 

pub type FieldVec<P, A> = FieldBuffer<P, <A as Allocator>::Vec<P>>;
A field buffer whose backing store is drawn from an allocator.

Over a buffer pool this is a recyclable pooled buffer. Over the global allocator it is an ordinary vector-backed buffer.

Aliased Type

pub struct FieldVec<P, A> { /* private fields */ }